@@ -5,8 +5,8 @@ import sys
 
 from django.utils.translation import ugettext_lazy as _
 
-from ...test import testcases
-from ...tests.models.utils import BaseModelDefinitionTestCase
+from mutant.test import testcases
+from mutant.tests.utils import BaseModelDefinitionTestCase
 
 from . import models
 
@@ -15,13 +15,14 @@ PACKAGE_PATH = os.path.dirname(sys.modules[__name__].__file__)
 MODULE_PATH = os.path.abspath(sys.modules[__name__].__file__)
 MODELS_MODULE_PATH = os.path.abspath(models.__file__)
 
+
 class FilePathFieldDefinitionTest(testcases.FieldDefinitionTestMixin,
                                   BaseModelDefinitionTestCase):
     field_definition_category = _('File')
     field_definition_cls = models.FilePathFieldDefinition
     field_definition_init_kwargs = {'path': PACKAGE_PATH}
     field_values = (MODULE_PATH, MODELS_MODULE_PATH)
-    
+
     def test_formfield(self):
         self.field.match = r'\.pyc?$'
         self.field.save()
