@@ -4,8 +4,8 @@ from decimal import Decimal
 
 from django.utils.translation import ugettext_lazy as _
 
-from ...test.testcases import FieldDefinitionTestMixin
-from ...tests.models.utils import BaseModelDefinitionTestCase
+from mutant.test.testcases import FieldDefinitionTestMixin
+from mutant.tests.utils import BaseModelDefinitionTestCase
 
 from .models import (BigIntegerFieldDefinition, DecimalFieldDefinition,
     FloatFieldDefinition, IntegerFieldDefinition,
