@@ -4,11 +4,15 @@ from django.db.models import fields
 from django.utils.translation import ugettext_lazy as _
 
 from ...models.field import FieldDefinition
+from ...models.field.managers import FieldDefinitionManager
 
 
 class CharFieldDefinition(FieldDefinition):
-    max_length = fields.PositiveSmallIntegerField(_('max length'),
-                                                  blank=True, null=True)
+    max_length = fields.PositiveSmallIntegerField(
+        _('max length'), blank=True, null=True
+    )
+
+    objects = FieldDefinitionManager()
 
     class Meta:
         app_label = 'mutant'
@@ -17,6 +21,7 @@ class CharFieldDefinition(FieldDefinition):
         defined_field_description = _('String')
         defined_field_category = _('Text')
 
+
 class TextFieldDefinition(CharFieldDefinition):
     class Meta:
         app_label = 'mutant'
